TuckERInteraction
=================

.. currentmodule:: pykeen.nn.modules

.. autoclass:: TuckERInteraction
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~TuckERInteraction.default_core_initializer_kwargs

   .. rubric:: Methods Summary

   .. autosummary::

      ~TuckERInteraction.default_core_initializer
      ~TuckERInteraction.forward
      ~TuckERInteraction.reset_parameters

   .. rubric:: Attributes Documentation

   .. autoattribute:: default_core_initializer_kwargs

   .. rubric:: Methods Documentation

   .. automethod:: default_core_initializer
   .. automethod:: forward
   .. automethod:: reset_parameters
